--- lablgtkextras-1.0.orig/checkocaml.ml	2011-01-13 08:39:06.000000000 +0100
+++ lablgtkextras-1.0/checkocaml.ml	2011-05-06 13:58:36.000000000 +0200
@@ -836,6 +836,37 @@
   iter includes
 (*/c==v=[OCaml_conf.detect_lablgtk2]=0.1====*)
 
+(*c==v=[OCaml_conf.detect_xml_light]=0.3====*)
+let detect_xml_light ?(modes=[`Byte;`Opt]) conf =
+  let includes =
+     ["default install", [] ;
+      "+xml-light style", [Filename.concat (ocaml_libdir conf) "xml-light"] ;
+     ]
+  in
+  let includes =
+    match ocamlfind_query conf "xml-light" with
+      None -> includes
+    | Some s -> ("with ocamlfind", [s]) :: includes
+  in
+  let libs = ["xml-light.cma"] in
+  let f (mes, includes) mode =
+    let mes = Printf.sprintf "checking for Xml-light (%s) %s... "
+	(string_of_mode mode) mes
+    in
+    can_link ~mes mode conf ~includes ~libs []
+  in
+  let rec iter = function
+      [] -> ([], [])
+    | incs :: q ->
+	let f = f incs in
+	if List.for_all f modes then
+	  (snd incs, libs)
+	else
+	  iter q
+  in
+  iter includes
+(*/c==v=[OCaml_conf.detect_xml_light]=0.3====*)
+
 let detect_cairo ?(modes=[`Byte;`Opt]) conf =
   let includes = ["default install", ["+cairo"]] in
   let includes =
@@ -894,6 +925,11 @@
   | s, _ -> add_subst "LABLGTK2_INCLUDES" s
 ;;
 let _ =
+  match detect_xml_light ~modes conf with
+    [], [] -> !fatal_error "Could not link with Xml-light"
+  | l, _ -> add_subst "XMLLIGHT_INCLUDES" (string_of_includes l)
+;;
+let _ =
   let lablgladecc =
     try ocaml_prog "lablgladecc2"
     with Program_not_found _ ->
--- lablgtkextras-1.0.orig/master.Makefile.in	2011-01-13 08:39:06.000000000 +0100
+++ lablgtkextras-1.0/master.Makefile.in	2011-05-06 15:53:47.000000000 +0200
@@ -74,6 +74,7 @@
 ROOT=@ROOT@
 
 LABLGTK2_INCLUDES= @LABLGTK2_INCLUDES@
+XMLLIGHT_INCLUDES=@XMLLIGHT_INCLUDES@
 
 # some common targets :
 #######################
--- lablgtkextras-1.0.orig/src/Makefile	2011-01-13 08:39:06.000000000 +0100
+++ lablgtkextras-1.0/src/Makefile	2011-05-06 15:56:22.000000000 +0200
@@ -27,7 +27,7 @@
 include ../master.Makefile
 
 MY_INCLUDES=
-SYSTEM_INCLUDES= $(LABLGTK2_INCLUDES)
+SYSTEM_INCLUDES= $(LABLGTK2_INCLUDES) $(XMLLIGHT_INCLUDES)
 
 INCLUDES=$(MY_INCLUDES) $(SYSTEM_INCLUDES)
 
--- lablgtkextras-1.0.orig/configure	2011-01-13 08:39:06.000000000 +0100
+++ lablgtkextras-1.0/configure	2011-05-06 16:02:43.000000000 +0200
@@ -556,6 +556,7 @@
 ac_unique_file="master.Makefile.in"
 ac_subst_vars='LTLIBOBJS
 LIBOBJS
+XMLLIGHT_INCLUDES
 LABLGTK2_INCLUDES
 CWLIB_BYTE
 CWLIB
--- lablgtkextras-1.0.orig/configure.ac	2011-01-13 08:39:06.000000000 +0100
+++ lablgtkextras-1.0/configure.ac	2011-05-06 16:00:35.000000000 +0200
@@ -153,6 +153,7 @@
 AC_SUBST(CWLIB_BYTE)
 
 AC_SUBST(LABLGTK2_INCLUDES)
+AC_SUBST(XMLLIGHT_INCLUDES)
 
 # Finally create the master.Makefile.in and other files
 ACFILES="master.Makefile src/version.ml src/install.ml"
